Class: Google::Apis::ComposerV1beta1::CheckUpgradeResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

Message containing information about the result of an upgrade check operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckUpgradeResponse

Returns a new instance of CheckUpgradeResponse.



152
153
154
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_log_uriString

Output only. Url for a docker build log of an upgraded image. Corresponds to the JSON property buildLogUri

Returns:

  • (String)


122
123
124
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 122

def build_log_uri
  @build_log_uri
end

#config_conflictsArray<Google::Apis::ComposerV1beta1::ConfigConflict>

Output only. Contains information about environment configuration that is incompatible with the new image version, except for pypi modules conflicts. Corresponds to the JSON property configConflicts



128
129
130
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 128

def config_conflicts
  @config_conflicts
end

#contains_pypi_modules_conflictString

Output only. Whether build has succeeded or failed on modules conflicts. Corresponds to the JSON property containsPypiModulesConflict

Returns:

  • (String)


133
134
135
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 133

def contains_pypi_modules_conflict
  @contains_pypi_modules_conflict
end

#image_versionString

Composer image for which the build was happening. Corresponds to the JSON property imageVersion

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 138

def image_version
  @image_version
end

#pypi_conflict_build_log_extractString

Output only. Extract from a docker image build log containing information about pypi modules conflicts. Corresponds to the JSON property pypiConflictBuildLogExtract

Returns:

  • (String)


144
145
146
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 144

def pypi_conflict_build_log_extract
  @pypi_conflict_build_log_extract
end

#pypi_dependenciesHash<String,String>

Pypi dependencies specified in the environment configuration, at the time when the build was triggered. Corresponds to the JSON property pypiDependencies

Returns:

  • (Hash<String,String>)


150
151
152
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 150

def pypi_dependencies
  @pypi_dependencies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



157
158
159
160
161
162
163
164
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 157

def update!(**args)
  @build_log_uri = args[:build_log_uri] if args.key?(:build_log_uri)
  @config_conflicts = args[:config_conflicts] if args.key?(:config_conflicts)
  @contains_pypi_modules_conflict = args[:contains_pypi_modules_conflict] if args.key?(:contains_pypi_modules_conflict)
  @image_version = args[:image_version] if args.key?(:image_version)
  @pypi_conflict_build_log_extract = args[:pypi_conflict_build_log_extract] if args.key?(:pypi_conflict_build_log_extract)
  @pypi_dependencies = args[:pypi_dependencies] if args.key?(:pypi_dependencies)
end