Class: Google::Apis::ComposerV1beta1::DagProcessorResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

Configuration for resources used by Airflow DAG processors. This field is supported for Cloud Composer environments in versions composer-3-airflow-..- build. and newer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DagProcessorResource

Returns a new instance of DagProcessorResource.



328
329
330
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Optional. The number of DAG processors. If not provided or set to 0, a single DAG processor instance will be created. Corresponds to the JSON property count

Returns:

  • (Fixnum)


309
310
311
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 309

def count
  @count
end

#cpuFloat

Optional. CPU request and limit for a single Airflow DAG processor replica. Corresponds to the JSON property cpu

Returns:

  • (Float)


314
315
316
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 314

def cpu
  @cpu
end

#memory_gbFloat

Optional. Memory (GB) request and limit for a single Airflow DAG processor replica. Corresponds to the JSON property memoryGb

Returns:

  • (Float)


320
321
322
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 320

def memory_gb
  @memory_gb
end

#storage_gbFloat

Optional. Storage (GB) request and limit for a single Airflow DAG processor replica. Corresponds to the JSON property storageGb

Returns:

  • (Float)


326
327
328
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 326

def storage_gb
  @storage_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



333
334
335
336
337
338
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 333

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @cpu = args[:cpu] if args.key?(:cpu)
  @memory_gb = args[:memory_gb] if args.key?(:memory_gb)
  @storage_gb = args[:storage_gb] if args.key?(:storage_gb)
end