Class: Google::Apis::ComposerV1beta1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



1114
1115
1116
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1099
1100
1101
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1099

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::ComposerV1beta1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1104
1105
1106
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1104

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1112
1113
1114
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1112

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1119
1120
1121
1122
1123
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1119

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end