Class: Google::Apis::ComposerV1beta1::ListUserWorkloadsSecretsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::ListUserWorkloadsSecretsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
The user workloads Secrets for a given environment.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The page token used to query for the next page if one exists.
-
#user_workloads_secrets ⇒ Array<Google::Apis::ComposerV1beta1::UserWorkloadsSecret>
The list of Secrets returned by a ListUserWorkloadsSecretsRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUserWorkloadsSecretsResponse
constructor
A new instance of ListUserWorkloadsSecretsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUserWorkloadsSecretsResponse
Returns a new instance of ListUserWorkloadsSecretsResponse.
1165 1166 1167 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The page token used to query for the next page if one exists.
Corresponds to the JSON property nextPageToken
1158 1159 1160 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1158 def next_page_token @next_page_token end |
#user_workloads_secrets ⇒ Array<Google::Apis::ComposerV1beta1::UserWorkloadsSecret>
The list of Secrets returned by a ListUserWorkloadsSecretsRequest.
Corresponds to the JSON property userWorkloadsSecrets
1163 1164 1165 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1163 def user_workloads_secrets @user_workloads_secrets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1170 1171 1172 1173 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1170 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @user_workloads_secrets = args[:user_workloads_secrets] if args.key?(:user_workloads_secrets) end |