Class: Google::Apis::ComposerV1beta1::MasterAuthorizedNetworksConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::MasterAuthorizedNetworksConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.
Instance Attribute Summary collapse
-
#cidr_blocks ⇒ Array<Google::Apis::ComposerV1beta1::CidrBlock>
Up to 50 external networks that could access Kubernetes master through HTTPS.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
constructor
A new instance of MasterAuthorizedNetworksConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
Returns a new instance of MasterAuthorizedNetworksConfig.
1324 1325 1326 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cidr_blocks ⇒ Array<Google::Apis::ComposerV1beta1::CidrBlock>
Up to 50 external networks that could access Kubernetes master through HTTPS.
Corresponds to the JSON property cidrBlocks
1316 1317 1318 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1316 def cidr_blocks @cidr_blocks end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Whether or not master authorized networks feature is enabled.
Corresponds to the JSON property enabled
1321 1322 1323 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1321 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1329 def update!(**args) @cidr_blocks = args[:cidr_blocks] if args.key?(:cidr_blocks) @enabled = args[:enabled] if args.key?(:enabled) end |