Class: Google::Apis::ComposerV1beta1::PollAirflowCommandRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

Poll Airflow Command request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PollAirflowCommandRequest

Returns a new instance of PollAirflowCommandRequest.



1659
1660
1661
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execution_idString

The unique ID of the command execution. Corresponds to the JSON property executionId

Returns:

  • (String)


1642
1643
1644
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1642

def execution_id
  @execution_id
end

#next_line_numberFixnum

Line number from which new logs should be fetched. Corresponds to the JSON property nextLineNumber

Returns:

  • (Fixnum)


1647
1648
1649
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1647

def next_line_number
  @next_line_number
end

#podString

The name of the pod where the command is executed. Corresponds to the JSON property pod

Returns:

  • (String)


1652
1653
1654
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1652

def pod
  @pod
end

#pod_namespaceString

The namespace of the pod where the command is executed. Corresponds to the JSON property podNamespace

Returns:

  • (String)


1657
1658
1659
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1657

def pod_namespace
  @pod_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1664
1665
1666
1667
1668
1669
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1664

def update!(**args)
  @execution_id = args[:execution_id] if args.key?(:execution_id)
  @next_line_number = args[:next_line_number] if args.key?(:next_line_number)
  @pod = args[:pod] if args.key?(:pod)
  @pod_namespace = args[:pod_namespace] if args.key?(:pod_namespace)
end