Class: Google::Apis::ComposerV1beta1::PrivateEnvironmentConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::PrivateEnvironmentConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
The configuration information for configuring a Private IP Cloud Composer environment.
Instance Attribute Summary collapse
-
#cloud_composer_connection_subnetwork ⇒ String
Optional.
-
#cloud_composer_network_ipv4_cidr_block ⇒ String
Optional.
-
#cloud_composer_network_ipv4_reserved_range ⇒ String
Output only.
-
#cloud_sql_ipv4_cidr_block ⇒ String
Optional.
-
#enable_private_builds_only ⇒ Boolean
(also: #enable_private_builds_only?)
Optional.
-
#enable_private_environment ⇒ Boolean
(also: #enable_private_environment?)
Optional.
-
#enable_privately_used_public_ips ⇒ Boolean
(also: #enable_privately_used_public_ips?)
Optional.
-
#networking_config ⇒ Google::Apis::ComposerV1beta1::NetworkingConfig
Configuration options for networking connections in the Composer 2 environment.
-
#networking_type ⇒ String
Optional.
-
#private_cluster_config ⇒ Google::Apis::ComposerV1beta1::PrivateClusterConfig
Configuration options for the private GKE cluster in a Cloud Composer environment.
-
#web_server_ipv4_cidr_block ⇒ String
Optional.
-
#web_server_ipv4_reserved_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateEnvironmentConfig
constructor
A new instance of PrivateEnvironmentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateEnvironmentConfig
Returns a new instance of PrivateEnvironmentConfig.
1846 1847 1848 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_composer_connection_subnetwork ⇒ String
Optional. When specified, the environment will use Private Service Connect
instead of VPC peerings to connect to Cloud SQL in the Tenant Project, and the
PSC endpoint in the Customer Project will use an IP address from this
subnetwork.
Corresponds to the JSON property cloudComposerConnectionSubnetwork
1762 1763 1764 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1762 def cloud_composer_connection_subnetwork @cloud_composer_connection_subnetwork end |
#cloud_composer_network_ipv4_cidr_block ⇒ String
Optional. The CIDR block from which IP range for Cloud Composer Network in
tenant project will be reserved. Needs to be disjoint from
private_cluster_config.master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block.
This field is supported for Cloud Composer environments in versions composer-2.
.-airflow-..* and newer.
Corresponds to the JSON property cloudComposerNetworkIpv4CidrBlock
1771 1772 1773 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1771 def cloud_composer_network_ipv4_cidr_block @cloud_composer_network_ipv4_cidr_block end |
#cloud_composer_network_ipv4_reserved_range ⇒ String
Output only. The IP range reserved for the tenant project's Cloud Composer
network. This field is supported for Cloud Composer environments in versions
composer-2..-airflow-..* and newer.
Corresponds to the JSON property cloudComposerNetworkIpv4ReservedRange
1778 1779 1780 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1778 def cloud_composer_network_ipv4_reserved_range @cloud_composer_network_ipv4_reserved_range end |
#cloud_sql_ipv4_cidr_block ⇒ String
Optional. The CIDR block from which IP range in tenant project will be
reserved for Cloud SQL. Needs to be disjoint from web_server_ipv4_cidr_block
Corresponds to the JSON property cloudSqlIpv4CidrBlock
1784 1785 1786 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1784 def cloud_sql_ipv4_cidr_block @cloud_sql_ipv4_cidr_block end |
#enable_private_builds_only ⇒ Boolean Also known as: enable_private_builds_only?
Optional. If true, builds performed during operations that install Python
packages have only private connectivity to Google services (including Artifact
Registry) and VPC network (if either NodeConfig.network and NodeConfig.
subnetwork fields or NodeConfig.composer_network_attachment field are
specified). If false, the builds also have access to the internet. This
field is supported for Cloud Composer environments in versions composer-3-
airflow-..-build. and newer.
Corresponds to the JSON property enablePrivateBuildsOnly
1795 1796 1797 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1795 def enable_private_builds_only @enable_private_builds_only end |
#enable_private_environment ⇒ Boolean Also known as: enable_private_environment?
Optional. If true, a Private IP Cloud Composer environment is created. If
this field is set to true, IPAllocationPolicy.use_ip_aliases must be set to
true for Cloud Composer environments in versions composer-1..-airflow-..*.
This field is going to be deprecated. Use networking_type instead.
Corresponds to the JSON property enablePrivateEnvironment
1804 1805 1806 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1804 def enable_private_environment @enable_private_environment end |
#enable_privately_used_public_ips ⇒ Boolean Also known as: enable_privately_used_public_ips?
Optional. When enabled, IPs from public (non-RFC1918) ranges can be used for
IPAllocationPolicy.cluster_ipv4_cidr_block and IPAllocationPolicy.
service_ipv4_cidr_block.
Corresponds to the JSON property enablePrivatelyUsedPublicIps
1812 1813 1814 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1812 def enable_privately_used_public_ips @enable_privately_used_public_ips end |
#networking_config ⇒ Google::Apis::ComposerV1beta1::NetworkingConfig
Configuration options for networking connections in the Composer 2 environment.
Corresponds to the JSON property networkingConfig
1818 1819 1820 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1818 def networking_config @networking_config end |
#networking_type ⇒ String
Optional. Networking type for the environment, either private or public.
Corresponds to the JSON property networkingType
1823 1824 1825 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1823 def networking_type @networking_type end |
#private_cluster_config ⇒ Google::Apis::ComposerV1beta1::PrivateClusterConfig
Configuration options for the private GKE cluster in a Cloud Composer
environment.
Corresponds to the JSON property privateClusterConfig
1829 1830 1831 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1829 def private_cluster_config @private_cluster_config end |
#web_server_ipv4_cidr_block ⇒ String
Optional. The CIDR block from which IP range for web server will be reserved.
Needs to be disjoint from private_cluster_config.master_ipv4_cidr_block and
cloud_sql_ipv4_cidr_block. This field is supported for Cloud Composer
environments in versions composer-1..-airflow-..*.
Corresponds to the JSON property webServerIpv4CidrBlock
1837 1838 1839 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1837 def web_server_ipv4_cidr_block @web_server_ipv4_cidr_block end |
#web_server_ipv4_reserved_range ⇒ String
Output only. The IP range reserved for the tenant project's App Engine VMs.
This field is supported for Cloud Composer environments in versions composer-1.
.-airflow-..*.
Corresponds to the JSON property webServerIpv4ReservedRange
1844 1845 1846 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1844 def web_server_ipv4_reserved_range @web_server_ipv4_reserved_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1851 def update!(**args) @cloud_composer_connection_subnetwork = args[:cloud_composer_connection_subnetwork] if args.key?(:cloud_composer_connection_subnetwork) @cloud_composer_network_ipv4_cidr_block = args[:cloud_composer_network_ipv4_cidr_block] if args.key?(:cloud_composer_network_ipv4_cidr_block) @cloud_composer_network_ipv4_reserved_range = args[:cloud_composer_network_ipv4_reserved_range] if args.key?(:cloud_composer_network_ipv4_reserved_range) @cloud_sql_ipv4_cidr_block = args[:cloud_sql_ipv4_cidr_block] if args.key?(:cloud_sql_ipv4_cidr_block) @enable_private_builds_only = args[:enable_private_builds_only] if args.key?(:enable_private_builds_only) @enable_private_environment = args[:enable_private_environment] if args.key?(:enable_private_environment) @enable_privately_used_public_ips = args[:enable_privately_used_public_ips] if args.key?(:enable_privately_used_public_ips) @networking_config = args[:networking_config] if args.key?(:networking_config) @networking_type = args[:networking_type] if args.key?(:networking_type) @private_cluster_config = args[:private_cluster_config] if args.key?(:private_cluster_config) @web_server_ipv4_cidr_block = args[:web_server_ipv4_cidr_block] if args.key?(:web_server_ipv4_cidr_block) @web_server_ipv4_reserved_range = args[:web_server_ipv4_reserved_range] if args.key?(:web_server_ipv4_reserved_range) end |