Class: Google::Apis::ComposerV1beta1::SoftwareConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::SoftwareConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Specifies the selection and configuration of software inside the environment.
Instance Attribute Summary collapse
-
#airflow_config_overrides ⇒ Hash<String,String>
Optional.
-
#cloud_data_lineage_integration ⇒ Google::Apis::ComposerV1beta1::CloudDataLineageIntegration
Configuration for Cloud Data Lineage integration.
-
#env_variables ⇒ Hash<String,String>
Optional.
-
#image_version ⇒ String
Optional.
-
#pypi_packages ⇒ Hash<String,String>
Optional.
-
#python_version ⇒ String
Optional.
-
#scheduler_count ⇒ Fixnum
Optional.
-
#web_server_plugins_mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SoftwareConfig
constructor
A new instance of SoftwareConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SoftwareConfig
Returns a new instance of SoftwareConfig.
2103 2104 2105 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#airflow_config_overrides ⇒ Hash<String,String>
Optional. Apache Airflow configuration properties to override. Property keys
contain the section and property names, separated by a hyphen, for example "
core-dags_are_paused_at_creation". Section names must not contain hyphens ("-")
, opening square brackets ("["), or closing square brackets ("]"). The
property name must not be empty and must not contain an equals sign ("=") or
semicolon (";"). Section and property names must not contain a period (".").
Apache Airflow configuration property names must be written in snake_case. Property values can contain any
character, and can be written in any lower/upper case format. Certain Apache
Airflow configuration property values are blocked, and cannot be overridden.
Corresponds to the JSON property airflowConfigOverrides
2030 2031 2032 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2030 def airflow_config_overrides @airflow_config_overrides end |
#cloud_data_lineage_integration ⇒ Google::Apis::ComposerV1beta1::CloudDataLineageIntegration
Configuration for Cloud Data Lineage integration.
Corresponds to the JSON property cloudDataLineageIntegration
2035 2036 2037 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2035 def cloud_data_lineage_integration @cloud_data_lineage_integration end |
#env_variables ⇒ Hash<String,String>
Optional. Additional environment variables to provide to the Apache Airflow
scheduler, worker, and webserver processes. Environment variable names must
match the regular expression a-zA-Z_*. They cannot specify Apache Airflow
software configuration overrides (they cannot match the regular expression
AIRFLOW__[A-Z0-9_]+__[A-Z0-9_]+), and they cannot match any of the following
reserved names: * AIRFLOW_HOME * C_FORCE_ROOT * CONTAINER_NAME *
DAGS_FOLDER * GCP_PROJECT * GCS_BUCKET * GKE_CLUSTER_NAME *
SQL_DATABASE * SQL_INSTANCE * SQL_PASSWORD * SQL_PROJECT * SQL_REGION
SQL_USERCorresponds to the JSON propertyenvVariables
2048 2049 2050 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2048 def env_variables @env_variables end |
#image_version ⇒ String
Optional. The version of the software running in the environment. This
encapsulates both the version of Cloud Composer functionality and the version
of Apache Airflow. It must match the regular expression composer-([0-9]+(\.[0-
9]+\.[0-9]+(-preview\.[0-9]+)?)?|latest)-airflow-([0-9]+(\.[0-9]+(\.[0-9]+)?)?)
. When used as input, the server also checks if the provided version is
supported and denies the request for an unsupported version. The Cloud
Composer portion of the image version is a full semantic version, or an alias in the form of major version number or latest. When
an alias is provided, the server replaces it with the current Cloud Composer
version that satisfies the alias. The Apache Airflow portion of the image
version is a full semantic version that points to one of the supported Apache
Airflow versions, or an alias in the form of only major or major.minor
versions specified. When an alias is provided, the server replaces it with the
latest Apache Airflow version that satisfies the alias and is supported in the
given Cloud Composer version. In all cases, the resolved image version is
stored in the same field. See also version list and versioning overview.
Corresponds to the JSON property imageVersion
2070 2071 2072 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2070 def image_version @image_version end |
#pypi_packages ⇒ Hash<String,String>
Optional. Custom Python Package Index (PyPI) packages to be installed in the
environment. Keys refer to the lowercase package name such as "numpy" and
values are the lowercase extras and version specifier such as "==1.12.0", "[
devel,gcp_api]", or "[devel]>=1.8.2, <1.9.2". To specify a package without
pinning it to a version specifier, use the empty string as the value.
Corresponds to the JSON property pypiPackages
2079 2080 2081 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2079 def pypi_packages @pypi_packages end |
#python_version ⇒ String
Optional. The major version of Python used to run the Apache Airflow scheduler,
worker, and webserver processes. Can be set to '2' or '3'. If not specified,
the default is '3'. Cannot be updated. This field is only supported for Cloud
Composer environments in versions composer-1..-airflow-..*. Environments
in newer versions always use Python major version 3.
Corresponds to the JSON property pythonVersion
2088 2089 2090 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2088 def python_version @python_version end |
#scheduler_count ⇒ Fixnum
Optional. The number of schedulers for Airflow. This field is supported for
Cloud Composer environments in versions composer-1..-airflow-2...
Corresponds to the JSON property schedulerCount
2094 2095 2096 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2094 def scheduler_count @scheduler_count end |
#web_server_plugins_mode ⇒ String
Optional. Whether or not the web server uses custom plugins. If unspecified,
the field defaults to PLUGINS_ENABLED. This field is supported for Cloud
Composer environments in versions composer-3-airflow-..-build. and newer.
Corresponds to the JSON property webServerPluginsMode
2101 2102 2103 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2101 def web_server_plugins_mode @web_server_plugins_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2108 def update!(**args) @airflow_config_overrides = args[:airflow_config_overrides] if args.key?(:airflow_config_overrides) @cloud_data_lineage_integration = args[:cloud_data_lineage_integration] if args.key?(:cloud_data_lineage_integration) @env_variables = args[:env_variables] if args.key?(:env_variables) @image_version = args[:image_version] if args.key?(:image_version) @pypi_packages = args[:pypi_packages] if args.key?(:pypi_packages) @python_version = args[:python_version] if args.key?(:python_version) @scheduler_count = args[:scheduler_count] if args.key?(:scheduler_count) @web_server_plugins_mode = args[:web_server_plugins_mode] if args.key?(:web_server_plugins_mode) end |