Class: Google::Apis::ComposerV1beta1::StopAirflowCommandRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

Stop Airflow Command request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopAirflowCommandRequest

Returns a new instance of StopAirflowCommandRequest.



2192
2193
2194
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execution_idString

The unique ID of the command execution. Corresponds to the JSON property executionId

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2173

def execution_id
  @execution_id
end

#forceBoolean Also known as: force?

If true, the execution is terminated forcefully (SIGKILL). If false, the execution is stopped gracefully, giving it time for cleanup. Corresponds to the JSON property force

Returns:

  • (Boolean)


2179
2180
2181
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2179

def force
  @force
end

#podString

The name of the pod where the command is executed. Corresponds to the JSON property pod

Returns:

  • (String)


2185
2186
2187
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2185

def pod
  @pod
end

#pod_namespaceString

The namespace of the pod where the command is executed. Corresponds to the JSON property podNamespace

Returns:

  • (String)


2190
2191
2192
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2190

def pod_namespace
  @pod_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2197
2198
2199
2200
2201
2202
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2197

def update!(**args)
  @execution_id = args[:execution_id] if args.key?(:execution_id)
  @force = args[:force] if args.key?(:force)
  @pod = args[:pod] if args.key?(:pod)
  @pod_namespace = args[:pod_namespace] if args.key?(:pod_namespace)
end