Class: Google::Apis::ComposerV1beta1::WorkerResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

Configuration for resources used by Airflow workers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerResource

Returns a new instance of WorkerResource.



2495
2496
2497
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpuFloat

Optional. CPU request and limit for a single Airflow worker replica. Corresponds to the JSON property cpu

Returns:

  • (Float)


2473
2474
2475
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2473

def cpu
  @cpu
end

#max_countFixnum

Optional. Maximum number of workers for autoscaling. Corresponds to the JSON property maxCount

Returns:

  • (Fixnum)


2478
2479
2480
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2478

def max_count
  @max_count
end

#memory_gbFloat

Optional. Memory (GB) request and limit for a single Airflow worker replica. Corresponds to the JSON property memoryGb

Returns:

  • (Float)


2483
2484
2485
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2483

def memory_gb
  @memory_gb
end

#min_countFixnum

Optional. Minimum number of workers for autoscaling. Corresponds to the JSON property minCount

Returns:

  • (Fixnum)


2488
2489
2490
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2488

def min_count
  @min_count
end

#storage_gbFloat

Optional. Storage (GB) request and limit for a single Airflow worker replica. Corresponds to the JSON property storageGb

Returns:

  • (Float)


2493
2494
2495
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2493

def storage_gb
  @storage_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2500
2501
2502
2503
2504
2505
2506
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2500

def update!(**args)
  @cpu = args[:cpu] if args.key?(:cpu)
  @max_count = args[:max_count] if args.key?(:max_count)
  @memory_gb = args[:memory_gb] if args.key?(:memory_gb)
  @min_count = args[:min_count] if args.key?(:min_count)
  @storage_gb = args[:storage_gb] if args.key?(:storage_gb)
end