Class: Google::Apis::ComposerV1beta1::DatabaseConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::DatabaseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
The configuration of Cloud SQL instance that is used by the Apache Airflow software.
Instance Attribute Summary collapse
-
#machine_type ⇒ String
Optional.
-
#zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseConfig
constructor
A new instance of DatabaseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseConfig
Returns a new instance of DatabaseConfig.
396 397 398 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_type ⇒ String
Optional. Cloud SQL machine type used by Airflow database. It has to be one of:
db-n1-standard-2, db-n1-standard-4, db-n1-standard-8 or db-n1-standard-16. If
not specified, db-n1-standard-2 will be used. Supported for Cloud Composer
environments in versions composer-1..-airflow-..*.
Corresponds to the JSON property machineType
385 386 387 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 385 def machine_type @machine_type end |
#zone ⇒ String
Optional. The Compute Engine zone where the Airflow database is created. If
zone is provided, it must be in the region selected for the environment. If
zone is not provided, a zone is automatically selected. The zone can only be
set during environment creation. Supported for Cloud Composer environments in
versions composer-2..-airflow-..*.
Corresponds to the JSON property zone
394 395 396 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 394 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
401 402 403 404 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 401 def update!(**args) @machine_type = args[:machine_type] if args.key?(:machine_type) @zone = args[:zone] if args.key?(:zone) end |