Class: Google::Apis::ComposerV1beta1::Environment
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::Environment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
An environment for running orchestration tasks.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::ComposerV1beta1::EnvironmentConfig
Configuration information for an environment.
-
#create_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
The current state of the environment.
-
#storage_config ⇒ Google::Apis::ComposerV1beta1::StorageConfig
The configuration for data storage in the environment.
-
#update_time ⇒ String
Output only.
-
#uuid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Environment
constructor
A new instance of Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Environment
Returns a new instance of Environment.
577 578 579 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::ComposerV1beta1::EnvironmentConfig
Configuration information for an environment.
Corresponds to the JSON property config
520 521 522 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 520 def config @config end |
#create_time ⇒ String
Output only. The time at which this environment was created.
Corresponds to the JSON property createTime
525 526 527 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 525 def create_time @create_time end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for this environment. The labels map can contain
no more than 64 entries. Entries of the labels map are UTF8 strings that
comply with the following restrictions: * Keys must conform to regexp: \pLl\
pLo0,62 * Values must conform to regexp: [\pLl\pLo\pN_-]0,63 *
Both keys and values are additionally constrained to be <= 128 bytes in size.
Corresponds to the JSON property labels
534 535 536 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 534 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the environment, in the form: "projects/
projectId/locations/locationId/environments/environmentId" EnvironmentId
must start with a lowercase letter followed by up to 63 lowercase letters,
numbers, or hyphens, and cannot end with a hyphen.
Corresponds to the JSON property name
542 543 544 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 542 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
547 548 549 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 547 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
553 554 555 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 553 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
The current state of the environment.
Corresponds to the JSON property state
559 560 561 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 559 def state @state end |
#storage_config ⇒ Google::Apis::ComposerV1beta1::StorageConfig
The configuration for data storage in the environment.
Corresponds to the JSON property storageConfig
564 565 566 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 564 def storage_config @storage_config end |
#update_time ⇒ String
Output only. The time at which this environment was last modified.
Corresponds to the JSON property updateTime
569 570 571 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 569 def update_time @update_time end |
#uuid ⇒ String
Output only. The UUID (Universally Unique IDentifier) associated with this
environment. This value is generated when the environment is created.
Corresponds to the JSON property uuid
575 576 577 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 575 def uuid @uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 582 def update!(**args) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @storage_config = args[:storage_config] if args.key?(:storage_config) @update_time = args[:update_time] if args.key?(:update_time) @uuid = args[:uuid] if args.key?(:uuid) end |