Class: Google::Apis::ComposerV1beta1::NetworkingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::NetworkingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Configuration options for networking connections in the Composer 2 environment.
Instance Attribute Summary collapse
-
#connection_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkingConfig
constructor
A new instance of NetworkingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkingConfig
Returns a new instance of NetworkingConfig.
1346 1347 1348 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_type ⇒ String
Optional. Indicates the user requested specific connection type between Tenant
and Customer projects. You cannot set networking connection type in public IP
environment.
Corresponds to the JSON property connectionType
1344 1345 1346 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1344 def connection_type @connection_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1351 1352 1353 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1351 def update!(**args) @connection_type = args[:connection_type] if args.key?(:connection_type) end |