Class: Google::Apis::ComposerV1beta1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::OperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Metadata describing an operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#operation_type ⇒ String
Output only.
-
#resource ⇒ String
Output only.
-
#resource_uuid ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
1620 1621 1622 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the operation was submitted to the server.
Corresponds to the JSON property createTime
1591 1592 1593 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1591 def create_time @create_time end |
#end_time ⇒ String
Output only. The time when the operation terminated, regardless of its success.
This field is unset if the operation is still ongoing.
Corresponds to the JSON property endTime
1597 1598 1599 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1597 def end_time @end_time end |
#operation_type ⇒ String
Output only. The type of operation being performed.
Corresponds to the JSON property operationType
1602 1603 1604 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1602 def operation_type @operation_type end |
#resource ⇒ String
Output only. The resource being operated on, as a relative resource name.
Corresponds to the JSON property resource
1608 1609 1610 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1608 def resource @resource end |
#resource_uuid ⇒ String
Output only. The UUID of the resource being operated on.
Corresponds to the JSON property resourceUuid
1613 1614 1615 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1613 def resource_uuid @resource_uuid end |
#state ⇒ String
Output only. The current operation state.
Corresponds to the JSON property state
1618 1619 1620 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1618 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1625 1626 1627 1628 1629 1630 1631 1632 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1625 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @operation_type = args[:operation_type] if args.key?(:operation_type) @resource = args[:resource] if args.key?(:resource) @resource_uuid = args[:resource_uuid] if args.key?(:resource_uuid) @state = args[:state] if args.key?(:state) end |