Class: Google::Apis::ComposerV1beta1::PollAirflowCommandResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::PollAirflowCommandResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Response to PollAirflowCommandRequest.
Instance Attribute Summary collapse
-
#exit_info ⇒ Google::Apis::ComposerV1beta1::ExitInfo
Information about how a command ended.
-
#output ⇒ Array<Google::Apis::ComposerV1beta1::Line>
Output from the command execution.
-
#output_end ⇒ Boolean
(also: #output_end?)
Whether the command execution has finished and there is no more output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PollAirflowCommandResponse
constructor
A new instance of PollAirflowCommandResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PollAirflowCommandResponse
Returns a new instance of PollAirflowCommandResponse.
1693 1694 1695 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exit_info ⇒ Google::Apis::ComposerV1beta1::ExitInfo
Information about how a command ended.
Corresponds to the JSON property exitInfo
1679 1680 1681 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1679 def exit_info @exit_info end |
#output ⇒ Array<Google::Apis::ComposerV1beta1::Line>
Output from the command execution. It may not contain the full output and the
caller may need to poll for more lines.
Corresponds to the JSON property output
1685 1686 1687 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1685 def output @output end |
#output_end ⇒ Boolean Also known as: output_end?
Whether the command execution has finished and there is no more output.
Corresponds to the JSON property outputEnd
1690 1691 1692 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1690 def output_end @output_end end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1698 1699 1700 1701 1702 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1698 def update!(**args) @exit_info = args[:exit_info] if args.key?(:exit_info) @output = args[:output] if args.key?(:output) @output_end = args[:output_end] if args.key?(:output_end) end |