Class: Google::Apis::ComposerV1beta1::ScheduledSnapshotsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb

Overview

The configuration for scheduled snapshot creation mechanism.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledSnapshotsConfig

Returns a new instance of ScheduledSnapshotsConfig.



1955
1956
1957
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Whether scheduled snapshots creation is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1933
1934
1935
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1933

def enabled
  @enabled
end

#snapshot_creation_scheduleString

Optional. The cron expression representing the time when snapshots creation mechanism runs. This field is subject to additional validation around frequency of execution. Corresponds to the JSON property snapshotCreationSchedule

Returns:

  • (String)


1941
1942
1943
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1941

def snapshot_creation_schedule
  @snapshot_creation_schedule
end

#snapshot_locationString

Optional. The Cloud Storage location for storing automatically created snapshots. Corresponds to the JSON property snapshotLocation

Returns:

  • (String)


1947
1948
1949
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1947

def snapshot_location
  @snapshot_location
end

#time_zoneString

Optional. Time zone that sets the context to interpret snapshot_creation_schedule. Corresponds to the JSON property timeZone

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1953

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1960
1961
1962
1963
1964
1965
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 1960

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @snapshot_creation_schedule = args[:snapshot_creation_schedule] if args.key?(:snapshot_creation_schedule)
  @snapshot_location = args[:snapshot_location] if args.key?(:snapshot_location)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end