Class: Google::Apis::ComposerV1beta1::TrafficRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1beta1::TrafficRoutingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1beta1/classes.rb,
lib/google/apis/composer_v1beta1/representations.rb,
lib/google/apis/composer_v1beta1/representations.rb
Overview
Configuration for network traffic routing from the Cloud Composer environment to other services.
Instance Attribute Summary collapse
-
#cloud_run_functions_routing ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrafficRoutingConfig
constructor
A new instance of TrafficRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrafficRoutingConfig
Returns a new instance of TrafficRoutingConfig.
2280 2281 2282 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_run_functions_routing ⇒ String
Optional. Controls how network traffic to Cloud Run functions is routed.
Corresponds to the JSON property cloudRunFunctionsRouting
2278 2279 2280 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2278 def cloud_run_functions_routing @cloud_run_functions_routing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2285 2286 2287 |
# File 'lib/google/apis/composer_v1beta1/classes.rb', line 2285 def update!(**args) @cloud_run_functions_routing = args[:cloud_run_functions_routing] if args.key?(:cloud_run_functions_routing) end |